# ZetaNet API Client

Official PHP client library for the ZetaNet API.

## Installation

You can install the package via composer:

```bash
composer require zetanet/api-client
```

## Usage

```php
<?php
require_once 'vendor/autoload.php';

$client = new ZetaNet\Client([
    'apiKey' => 'your_api_key_here',
    'baseUrl' => 'https://zetanet-api.incontrol.network/api'
]);

// ISRA Check
try {
    $result = $client->israCheck([
        'zipCode' => '1234AB',
        'houseNumber' => '42'
    ]);
    print_r($result);
} catch (ZetaNet\Exception\ApiException $e) {
    // Handle API errors (400, 401, etc.)
    echo "API Error: " . $e->getMessage();
    echo "Status Code: " . $e->getCode();
} catch (ZetaNet\Exception\NetworkException $e) {
    // Handle network errors
    echo "Network Error: " . $e->getMessage();
}

// Prequalification Check
try {
    $result = $client->prequalification([
        'zipCode' => '1234AB',
        'houseNumber' => '42',
        'hasBroadband' => false,
        'hasPhone' => true,
        'productType' => 'ADSLTele'
    ]);
    print_r($result);
} catch (ZetaNet\Exception\ApiException $e) {
    echo "API Error: " . $e->getMessage();
}

// Zipcode Check
try {
    $result = $client->zipcodeCheck([
        'zipCode' => '1234AB',
        'houseNumber' => '42',
        'portfolio' => 'Teleworker'
    ]);
    print_r($result);
} catch (ZetaNet\Exception\ApiException $e) {
    echo "API Error: " . $e->getMessage();
}
```

## Available Methods

### israCheck(array $params)
Perform an ISRA check for xDSL services at a specific address.

Required parameters:
- zipCode (string): Postal code
- houseNumber (string): House number

### prequalification(array $params)
Check service availability with detailed options.

Required parameters:
- zipCode (string): Postal code
- houseNumber (string): House number

Optional parameters:
- extension (string): House number extension
- hasBroadband (bool): Has existing broadband
- hasPhone (bool): Has existing phone service
- productType (string): Product type (default: 'ADSLTele')

### zipcodeCheck(array $params)
Check address availability with portfolio check.

Required parameters:
- zipCode (string): Postal code
- houseNumber (string): House number

Optional parameters:
- portfolio (string): Portfolio type (default: 'Teleworker')
- extension (string): House number extension

## Error Handling

The client throws two types of exceptions:

- `ZetaNet\Exception\ApiException`: For API-related errors (400, 401, etc.)
- `ZetaNet\Exception\NetworkException`: For network-related errors

## Support

For support, please contact support@zetadatacenters.nl
